Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(251)

Unified Diff: media/base/cdm_initialized_promise.h

Issue 2568463003: media: Rename MediaKeys to ContentDecryptionModule (Closed)
Patch Set: comments addressed Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/cdm_factory.h ('k') | media/base/cdm_initialized_promise.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/cdm_initialized_promise.h
diff --git a/media/base/cdm_initialized_promise.h b/media/base/cdm_initialized_promise.h
index 8e48f7cd0fa2b422ff1f54fcb0c831bf4869bfbb..f5b4868d7be5d328cc1c2ceb76b05f473402840b 100644
--- a/media/base/cdm_initialized_promise.h
+++ b/media/base/cdm_initialized_promise.h
@@ -14,15 +14,15 @@
namespace media {
-class MediaKeys;
+class ContentDecryptionModule;
-// Promise to be resolved when the CDM is initialized. It owns the MediaKeys
-// object until the initialization completes, which it then passes to
-// |cdm_created_cb|.
+// Promise to be resolved when the CDM is initialized. It owns the
+// ContentDecryptionModule object until the initialization completes, which it
+// then passes to |cdm_created_cb|.
class MEDIA_EXPORT CdmInitializedPromise : public SimpleCdmPromise {
public:
CdmInitializedPromise(const CdmCreatedCB& cdm_created_cb,
- const scoped_refptr<MediaKeys>& cdm);
+ const scoped_refptr<ContentDecryptionModule>& cdm);
~CdmInitializedPromise() override;
// SimpleCdmPromise implementation.
@@ -35,7 +35,7 @@ class MEDIA_EXPORT CdmInitializedPromise : public SimpleCdmPromise {
CdmCreatedCB cdm_created_cb_;
// Holds a ref-count of the CDM.
- scoped_refptr<MediaKeys> cdm_;
+ scoped_refptr<ContentDecryptionModule> cdm_;
};
} // namespace media
« no previous file with comments | « media/base/cdm_factory.h ('k') | media/base/cdm_initialized_promise.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698